@@ -3,17 +3,20 @@ package TestApp::Component::HTML::Template;
 use strict;
 use base 'Catalyst::View::HTML::Template';
 
+use MRO::Compat;
+
 sub new {
     my $self = shift;
+
     $self->config(
         {
             die_on_bad_params => 0,
-            path              => [
-                TestApp->path_to( 'root', 'src', 'tmpl' ),
-            ],
+            path              => 
+                TestApp->path_to( 'root', 'src', 'tmpl' ) . '',
         },
     );
-    return $self->NEXT::new(@_);
+    
+    return $self = $self->maybe::next::method(@_)
 }
 
 1;
